################################################################################
################################################################################
#
#     Early Learning in South Punjab, Pakistan: 
#     Investigating Child Development and Classroom Quality
#
#     Primary R Script
#
################################################################################

### PURPOSE:      Analyze ECD outcomes and ECE Quality Data from Pakistan 

### OUTLINE:      

  ### PART 0: Standardize settings and install packages
  ### PART 1: Set file paths
  ### PART 2: Call the task-specific .R scripts 
  ### PART 3: Additional Analyses (outside of R)

### IDENTIFYING VARIABLES

###### Class/teacher/observation: merge_class_id
###### Child/Caregiver: childid

### NOTES:
  
### WRITTEN BY: Jonathan Seiden

### LAST DATE MODIFIED: 15 Mar 2024

################################################################################
#       PART 0:  INSTALL PACKAGES AND STANDARDIZE SETTINGS
################################################################################

### Ensure Pacman is installed
if (!require("pacman")) install.packages("pacman")

### Load required packages
pacman::p_load(psych, readxl, writexl, lavaan, tidyverse, readstata13)

################################################################################
#       PART 1:  SET FILE PATHS
################################################################################

###  This filepath needs to be set to the "DataWork" file


################################################################################
#       PART 2:  CALL TASK-SPECIFIC R SCRIPTS
################################################################################

### Load raw datasets and clean each, saving clean, anonymized datasets
### NOTE: This task is commented out and the reproducibility script should start 
### with the anonymized datasets in construction.  
# source("R/load_clean.R")

###  Construct variables at the child, class, and teacher level. Create various
### analytical datasets at the item, element (Teach ECE) and item level (AIM-ECD DA)
source("R/construction.R")

###  Create analysis file
source("R/analysis.R")

################################################################################
#       PART 3:  ADDITIONAL ANALYSIS (OUTSIDE OF R)
################################################################################

### The remainder of output comes from a Stata .do file. 