* ********************************************************************* *
* ********************************************************************* *
*                                                                       *
*              Early Learning in South Punjab, Pakistan:                *
*              Investigating Child Development and Classroom Quality    *
*              SUPPORTING DO_FILE                                       *
*                                                                       *
* ********************************************************************* *
* ********************************************************************* *

    /*
    ** PURPOSE:      Supporting analysis of MICS data on Pakistan 

    ** OUTLINE:      PART 1: Set globals for dynamic file paths and settings
                     PART 2: Call the task-specific do-files 

    ** IDS VAR:      Class/teacher/observation: merge_class_id
                     Child/Caregiver: childid

    ** NOTES:  The Stata .do files (including this one) only works if the Primary R Script 
    (Primary R Script.R) has been run first

    ** WRITTEN BY:   Jonathan Seiden

    ** Last date modified:  6 Mar 2024
    */

* ******************************************************************** *
*
*       PART 1:  Set globals for dynamic file paths and settings
*
* ******************************************************************** *

*** Only this line needs to be edited for a new user. All others will work 
global projectfolder       "."

global dataWorkFolder      "$projectfolder"
global rawdata             "$dataWorkFolder/rawdata" 
global cleandata           "$dataWorkFolder/cleandata" 
global output              "$dataWorkFolder/output" 
global dofiles             "$dataWorkFolder/dofiles"

sysdir set PLUS "${dofiles}/ado"
version 16

*** Create some graph settings
graph set window fontface "TT Arial"

* ******************************************************************** *
*
*       PART 2: - Call the task-specific do-files
*
* ******************************************************************** *

*** PART 1: Clean and Format data for Stata
*** This .do file cleans up two data files:
    * MICS data for a South Punjab, PHCIP, and Sample-level descriptive table of schools/enrollment
    * The data file of merged data from R with Child, Teach ECE, and Teacher data (at child level)

do "$dofiles/clean.do"

*** PART 2: Call the task-specific do-files
*** This .do file does the analysis on the cleaned data 
    * Table 2 (using MICS) 
    * Model building, margins, and several appendices (using child-level data)

do "$dofiles/analysis.do"
