
********************************************************************************
*
*     Early Learning in South Punjab, Pakistan: 
*     Investigating Child Development and Classroom Quality
*
*     Stata .do file 2: Supplementary Analyses
*
********************************************************************************

****************
**** Table 1. Share of 3 to 4-year-old Children Enrolled in ECE and Share Reported to be Developmentally on Track
****************

use "$cleandata/mics_clean.dta", clear

	************
	*** Use the survey weights to calculate ECE attendance and ECDI on-track for
	*** boys and girls in Punjab, South Punjab, and Central & North Punjab
	*** and store results in matrices
	************

	*** Punjab Overall
		*** All
		svy linearized: mean ecdi
			mat define ECDI_PunjabOverall = r(table)
		svy linearized: mean ECE
			mat define ECE_PunjabOverall = r(table)		
		*** Boys
		svy linearized: mean ecdi if HL4 == 1
			mat define ECDI_PunjabOverall_male = r(table)
		svy linearized: mean ECE if HL4 == 1
			mat define ECE_PunjabOverall_male = r(table)		
		*** Girls
		svy linearized: mean ecdi if HL4 == 2
			mat define ECDI_PunjabOverall_female = r(table)
		svy linearized: mean ECE if HL4 == 2
			mat define ECE_PunjabOverall_female = r(table)

	*** South Punjab
		*** All
		svy linearized: mean ecdi if SouthPunjab == 1
			mat define ECDI_SouthPunjab = r(table)
		svy linearized: mean ECE if SouthPunjab == 1
			mat define ECE_SouthPunjab = r(table)		
		*** Boys
		svy linearized: mean ecdi if HL4 == 1 & SouthPunjab == 1
			mat define ECDI_SouthPunjab_male = r(table)
		svy linearized: mean ECE if HL4 == 1 & SouthPunjab == 1
			mat define ECE_SouthPunjab_male = r(table)		
		*** Girls
		svy linearized: mean ecdi if HL4 == 2 & SouthPunjab == 1
			mat define ECDI_SouthPunjab_female = r(table)
		svy linearized: mean ECE if HL4 == 2 & SouthPunjab == 1
			mat define ECE_SouthPunjab_female = r(table)
			
	*** North Central Punjab
		*** All
		svy linearized: mean ecdi if SouthPunjab == 0
			mat define ECDI_NorthCentralPunjab = r(table)
		svy linearized: mean ECE if SouthPunjab == 0
			mat define ECE_NorthCentralPunjab = r(table)		
		*** Boys
		svy linearized: mean ecdi if HL4 == 1 & SouthPunjab == 0
			mat define ECDI_NorthCentralPunjab_male = r(table)
		svy linearized: mean ECE if HL4 == 1 & SouthPunjab == 0
			mat define ECE_NorthCentralPunjab_male = r(table)		
		*** Girls
		svy linearized: mean ecdi if HL4 == 2 & SouthPunjab == 0
			mat define ECDI_NorthCentralPunjab_female = r(table)
		svy linearized: mean ECE if HL4 == 2 & SouthPunjab == 0
			mat define ECE_NorthCentralPunjab_female = r(table)

	***********
	*** Put out all results into a formatted table in Excel
	putexcel set "$output/Table1.xlsx", replace
	***********

	*** Create Column headers
	putexcel B1 = "% Enrolled in ECE" B2 = "Mean" C2 = "95% Confidence Interval" D1 = "% Developmentally on Track" D2 = "Mean" E2 = "95% Confidence Interval"
	putexcel (B1:C1), merge 
	putexcel (D1:E1), merge 

	*** Create Row Titles
	putexcel A2 = "South Punjab" A3 = "   Male" A4 = "   Female" A5 = "Central & North Punjab" A6 = "   Male" A7 = "   Female" ///
	A8 = "Punjab Overall" A9 = "   Male" A10 = "   Female" 

	***
	local row = 2
	foreach matrix in ///
		SouthPunjab 		SouthPunjab_male 			SouthPunjab_female ///
		NorthCentralPunjab	NorthCentralPunjab_male		NorthCentralPunjab_female ///
		PunjabOverall		PunjabOverall_male			PunjabOverall_female {
		
		local mean = string(ECE_`matrix'["b", 1]*100,"%9.2f")
		local ll = string(ECE_`matrix'["ll", 1]*100,"%9.2f")
		local ul = string(ECE_`matrix'["ul", 1]*100,"%9.2f")
		local ci = "(`ll', `ul')"	
		putexcel B`row' = "`mean'" C`row' = "`ci'"
		
		local mean = string(ECDI_`matrix'["b", 1]*100,"%9.2f")
		local ll = string(ECDI_`matrix'["ll", 1]*100,"%9.2f")
		local ul = string(ECDI_`matrix'["ul", 1]*100,"%9.2f")
		local ci = "(`ll', `ul')"
		putexcel D`row' = "`mean'" E`row' = "`ci'"
		
		local ++row
	}

****************
**** Table 8. Model Building Process for AIM-ECD Overall Z-scores by Teach ECE Overall Z-scores
****************

use "$cleandata\analysis_data_stata", clear


*** Fit the model building process and store results
estimates clear
eststo model1: mixed AIMECD_Overall_Z TeachECE_Overall_Z  || aimecd_enumerator: || merge_class_id:
eststo model2: mixed AIMECD_Overall_Z TeachECE_Overall_Z  Age female  || aimecd_enumerator: || merge_class_id:
eststo model3: mixed AIMECD_Overall_Z TeachECE_Overall_Z  Age female Multigrade_Class class_Grade_1 || aimecd_enumerator: || merge_class_id:
eststo model4: mixed AIMECD_Overall_Z TeachECE_Overall_Z  Age female Multigrade_Class class_Grade_1 multigradeXClass || aimecd_enumerator: || merge_class_id:
eststo model5: mixed AIMECD_Overall_Z TeachECE_Overall_Z  Age female Multigrade_Class class_Grade_1 multigradeXClass teacher_cert_bin teacher_experience_3yr teacher_female || aimecd_enumerator: || merge_class_id: 
eststo model6: mixed AIMECD_Overall_Z TeachECE_Overall_Z  Age female Multigrade_Class class_Grade_1 multigradeXClass teacher_cert_bin teacher_experience_3yr teacher_female language_Saraiki language_Other || aimecd_enumerator: || merge_class_id:

*** Convert ln(variance) to variance
foreach model in model1 model2 model3 model4 model5 model6 {
	estimates restore `model'
	foreach v in s1_1_1 s2_1_1 sig_e {
		estadd scalar  v`v'= (exp(`=e(b)[1, "ln`v':_cons"]'))^2
	}
	estimates store `model'
}

*** Estout results of model building process
esttab model? using "$output/Table8.rtf", se label replace nomtitles nodepvars onecell star(~ 0.1 * 0.05 ** 0.01 *** 0.001)  modelwidth(5) keep(`e(depvar)':) stats(N vs1_1_1 vs2_1_1 vsig_e, labels(N "Var u_k (Enum)" "Var u_j (Class)" "Var e_ijk (Residual)"))

****************
**** Appendix D. Regression Table Panel A: AIM-ECD Domain Z-scores Predicted by Teach ECE Overall Z-scores
****************

*** Fit quality domain and AIM-ECD domain models
eststo modelA1: mixed EarlyLiteracy_Z TeachECE_Overall_Z  Age female Multigrade_Class class_Grade_1 multigradeXClass teacher_cert_bin teacher_experience_3yr teacher_female language_Saraiki language_Other || aimecd_enumerator: || merge_class_id:
eststo modelA2: mixed EarlyNumeracy_Z TeachECE_Overall_Z  Age female Multigrade_Class class_Grade_1 multigradeXClass teacher_cert_bin teacher_experience_3yr teacher_female language_Saraiki language_Other || aimecd_enumerator: || merge_class_id:
eststo modelA3: mixed ExecutiveFunction_Z TeachECE_Overall_Z  Age female Multigrade_Class class_Grade_1 multigradeXClass teacher_cert_bin teacher_experience_3yr teacher_female language_Saraiki language_Other || aimecd_enumerator: || merge_class_id:
eststo modelA4: mixed SocialEmotional_Z TeachECE_Overall_Z  Age female Multigrade_Class class_Grade_1 multigradeXClass teacher_cert_bin teacher_experience_3yr teacher_female language_Saraiki language_Other || aimecd_enumerator: || merge_class_id:

eststo modelB1: mixed AIMECD_Overall_Z TimeOnTask_level_Z  Age female Multigrade_Class class_Grade_1 multigradeXClass teacher_cert_bin teacher_experience_3yr teacher_female language_Saraiki language_Other || aimecd_enumerator: || merge_class_id:
eststo modelB2: mixed AIMECD_Overall_Z ClassroomCulture_Z  Age female Multigrade_Class class_Grade_1 multigradeXClass teacher_cert_bin teacher_experience_3yr teacher_female language_Saraiki language_Other || aimecd_enumerator: || merge_class_id:
eststo modelB3: mixed AIMECD_Overall_Z GuidedLearning_Z  Age female Multigrade_Class class_Grade_1 multigradeXClass teacher_cert_bin teacher_experience_3yr teacher_female language_Saraiki language_Other || aimecd_enumerator: || merge_class_id:
eststo modelB4: mixed AIMECD_Overall_Z SocioEmotionalSkills_Z  Age female Multigrade_Class class_Grade_1 multigradeXClass teacher_cert_bin teacher_experience_3yr teacher_female language_Saraiki language_Other || aimecd_enumerator: || merge_class_id:

*** Estout results of domain and quality models
foreach model in modelA1 modelA2 modelA3 modelA4 modelB1 modelB2 modelB3 modelB4 {
	estimates restore `model'
	foreach v in s1_1_1 s2_1_1 sig_e {
		estadd scalar  v`v'= (exp(`=e(b)[1, "ln`v':_cons"]'))^2
	}
	estimates store `model'
}

esttab modelA* using "$output/AppendixD_PanelA.rtf", replace se label onecell nogaps star(~ 0.1 * 0.05 ** 0.01 *** 0.001) modelwidth(8) stats(N vs1_1_1 vs2_1_1 vsig_e, labels(N "Var u_k (Enum)" "Var u_j (Class)" "Var e_ijk (Residual)")) 

esttab modelB* using "$output/AppendixD_PanelB.rtf", se label replace nodepvars onecell nogaps star(~ 0.1 * 0.05 ** 0.01 *** 0.001)  modelwidth(8) ///
	order(TimeOnTask_level_Z ClassroomCulture_Z GuidedLearning_Z SocioEmotionalSkills_Z) stats(N vs1_1_1 vs2_1_1 vsig_e, labels(N "Var u_k (Enum)" "Var u_j (Class)" "Var e_ijk (Residual)"))
	
****************
**** Figure 21. Predicted AIM-ECD Z-Scores by Child Age and Teach ECE Overall Quality Score
****************

estimates restore model6
margins,  at(Age = (4 5 6) TeachECE_Overall_Z = (-2 0 2))
marginsplot, legend(pos(6) order(1 "Low Quality" 2 "Average Quality" 3 "High quality")) level(68)  ///
	ytitle("Predicted AIM-ECD Overall Z-score") title("") graphregion(margin(small)) ///
	plot1opts(lcolor("102 194 165") mcolor("102 194 165")) ///
	plot2opts(lcolor("252 141 98") mcolor("252 141 98")) ///
	plot3opts(lcolor("231 138 195") mcolor("231 138 195")) ///
	ci1opts(lcolor("102 194 165") mcolor("102 194 165")) ///
	ci2opts(lcolor("252 141 98") mcolor("252 141 98")) ///
	ci3opts(lcolor("231 138 195") mcolor("231 138 195")) 

graph export "$output/Figure21.png", width(1000) height(800) replace

****************
**** Figure 22. AIM-ECD Domain Z-scores Predicted by Teach ECE Overall Quality
****************

estimates restore modelA1
margins,  at(TeachECE_Overall_Z = (-2 0 2))
marginsplot, legend(pos(6)) xlabel(-2 "Low Quality" 0 "Average Quality" 2 "High quality") title("Early Literacy") ///
	ytitle("Predicted Z-score") xtitle("") recast(bar) plotopts(fcolor("102 194 165") lcolor(none)) ciopts(lcolor("black")) level(68) 
	graph save early_literacy.gph, replace

estimates restore modelA2
margins,  at(TeachECE_Overall_Z = (-2 0 2))
marginsplot, legend(pos(6)) xlabel(-2 "Low Quality" 0 "Average Quality" 2 "High quality") title("Early Numeracy") ///
	ytitle("Predicted Z-score") xtitle("") recast(bar) plotopts(fcolor("252 141 98") lcolor(none)) ciopts(lcolor("black")) level(68) 
	graph save early_numeracy.gph, replace

estimates restore modelA3
margins,  at(TeachECE_Overall_Z = (-2 0 2))
marginsplot, legend(pos(6)) xlabel(-2 "Low Quality" 0 "Average Quality" 2 "High quality") title("Executive Functioning") ///
	ytitle("Predicted Z-score") xtitle("") recast(bar) plotopts(fcolor("231 138 195") lcolor(none)) ciopts(lcolor("black")) level(68) 
	graph save executive_function.gph, replace 

estimates restore modelA4
margins,  at(TeachECE_Overall_Z = (-2 0 2))
marginsplot, legend(pos(6)) xlabel(-2 "Low Quality" 0 "Average Quality" 2 "High quality") title("Social-Emotional") ///
	ytitle("Predicted Z-score") xtitle("") recast(bar) plotopts(fcolor("166 216 84") lcolor(none)) ciopts(lcolor("black")) level(68) 
	graph save social_emotional.gph, replace

graph combine early_literacy.gph early_numeracy.gph executive_function.gph social_emotional.gph, ycommon 
graph export "$output/Figure22.png", width(1400) height(1000) replace

rm "early_literacy.gph" 
rm "early_numeracy.gph" 
rm "executive_function.gph" 
rm "social_emotional.gph"

****************
**** Figure 22. AIM-ECD Domain Z-scores Predicted by Teach ECE Overall Quality
****************

estimates restore modelB1
margins,  at(TimeOnTask_level_Z = (-2 0 2))
marginsplot, legend(pos(6)) ylabel(-2 "Low Quality" 0 "Average Quality" 2 "High quality") title("Time on Task") horizontal ///
	ytitle("") xtitle("") recast(bar) plotopts(fcolor("90 169 177") lcolor(none)) ciopts(lcolor("black")) level(68) 
	graph save time_on_task.gph, replace

estimates restore modelB2
margins,  at(ClassroomCulture_Z = (-2 0 2))
marginsplot, legend(pos(6)) ylabel(-2 "Low Quality" 0 "Average Quality" 2 "High quality") title("Classroom Culture") horizontal ///
	ytitle("") xtitle("") recast(bar) plotopts(fcolor("232 228 74") lcolor(none)) ciopts(lcolor("black")) level(68) 
	graph save classroom_culture.gph, replace

estimates restore modelB3
margins,  at(GuidedLearning_Z = (-2 0 2))
marginsplot, legend(pos(6)) ylabel(-2 "Low Quality" 0 "Average Quality" 2 "High quality") title("Guided Learning") horizontal ///
	ytitle("") xtitle("") recast(bar) plotopts(fcolor("178 85 147") lcolor(none)) ciopts(lcolor("black")) level(68) 
	graph save guided_learning.gph, replace 

estimates restore modelB4
margins,  at(SocioEmotionalSkills_Z = (-2 0 2))
marginsplot, legend(pos(6)) ylabel(-2 "Low Quality" 0 "Average Quality" 2 "High quality") title("Socioemotional Skills") horizontal ///
	ytitle("") xtitle("") recast(bar) plotopts(fcolor("249 166 77") lcolor(none)) ciopts(lcolor("black")) level(68) 
	graph save socioemotional_skills.gph, replace

graph combine time_on_task.gph classroom_culture.gph guided_learning.gph socioemotional_skills.gph, ycommon xcommon
graph export "$output/Figure23.png", width(1400) height(1000) replace

rm "time_on_task.gph " 
rm "classroom_culture.gph" 
rm "guided_learning.gph" 
rm "socioemotional_skills.gph"
