********************************************************************************
*
*     Early Learning in South Punjab, Pakistan: 
*     Investigating Child Development and Classroom Quality
*
*     Stata .do file 1: Clean and Format data for Stata  
*
********************************************************************************

****************
**** Clean and format MICS data
****************

use "$rawdata/ch_hl_hh.dta", clear

	*** Create a variable for ECE 
	gen ECE = 1 if UB6 == 1
		replace ECE = 0 if UB6 == 2
		
	*** Create a variable for South Punjab
	* 1				2			34		4				35		5		24		36			6				3				7
	* Bahawalnagar	Bahawalpur	Bhakkar	Dera Ghazi Khan	Khushab	Layyah	Lodhran	Mianwali	Muzaffargarh	Rahim Yar Khan	Rajanpur
	gen SouthPunjab = 1 if inlist(hh7, 1, 2, 34, 4, 35, 5, 24, 36, 6, 3, 7)
		replace SouthPunjab = 0 if !inlist(hh7, 1, 2, 34, 4, 35, 5, 24, 36, 6, 3, 7)

	save "$cleandata/mics_clean.dta", replace

****************
**** Format child-level analysis data from .R
****************

	use "$cleandata\analysis_data", clear

	*** Convert some factor variables to dichotomous to make runnning regressions easier 
	gen class_Grade_1 = Class == 3
	gen language_Saraiki = language_used == 2
	gen language_Other = language_used == 3 
	gen teacher_cert_bin = teacher_cert != 1
	gen teacher_experience_3yr = teacher_experience >= 4
	gen multigradeXClass = class_Grade_1 & Multigrade_Class == 1
	gen teacher_female = Teacher_Gender == "Female"

	*** Label predictors
	la var Age "Child's age" 
	la var female "Child is female" 
	la var Multigrade_Class "Multigraded class" 
	la var class_Grade_1 "Grade 1 class" 
	la var teacher_cert_bin "Teacher has teaching certificate or ed. degree" 
	la var teacher_experience "Number of years of ECE experience"
	la var teacher_experience_3yr "Teacher has 3+ years pre-primary experience"
	la var teacher_female "Teacher is female" 
	la var language_Saraiki "Saraiki language class" 
	la var language_Other "Other language class"
	la var multigradeXClass "Multigraded X Grade 1"

	*** Label AIM-ECD domains
	la var AIMECD_Overall_Z "AIM-ECD Overall Z-score"
	la var EarlyLiteracy_Z "AIM-ECD Early Literacy Z-score"
	la var EarlyNumeracy_Z "AIM-ECD Early Numeracy Z-score"
	la var ExecutiveFunction_Z "AIM-ECD Executive Functioning Z-score"
	la var SocialEmotional_Z "AIM-ECD Social-Emotional Z-score"
	la var EnglishLetter_Z "AIM-ECD English Letters Z-score"

	*** Label Teach ECE Areas
	la var TeachECE_Overall_Z "Teach ECE Overall Z-score" 
	la var TimeOnTask_level_Z "Teach ECE Time on Task Z-score"
	la var ClassroomCulture_Z "Teach ECE Classroom Culture Z-score"
	la var GuidedLearning_Z "Teach ECE Guided Learning Z-score"
	la var SocioEmotionalSkills_Z "Teach ECE Socioemotional Skills Z-score"

	save "$cleandata\analysis_data_stata", replace
